pub struct OutpostIdPrefix(/* private fields */);Expand description
Validated ID prefix accepted from human selectors.
Prefixes are accepted only when they are at least five hex characters and uniquely identify one entry within the current source registry.
Implementations