pub struct ResolvedOutpostEntry {
pub entry: RegistryEntry,
pub path: PathBuf,
}Expand description
Registry entry resolved from an OutpostSelector.
The resolved registry entry and canonical registry path for an
OutpostSelector.
Fields
entry: RegistryEntrypath: PathBufTrait Implementations
Sourceimpl Clone for ResolvedOutpostEntry
impl Clone for ResolvedOutpostEntry
Sourcefn clone(&self) -> ResolvedOutpostEntry
fn clone(&self) -> ResolvedOutpostEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedOutpostEntry
impl Debug for ResolvedOutpostEntry
impl Eq for ResolvedOutpostEntry
Sourceimpl PartialEq for ResolvedOutpostEntry
impl PartialEq for ResolvedOutpostEntry
Sourcefn eq(&self, other: &ResolvedOutpostEntry) -> bool
fn eq(&self, other: &ResolvedOutpostEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ResolvedOutpostEntry